package com.xyzc.common.core.exception;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * 错误编码
 *
 */
@Getter
@AllArgsConstructor
public enum ErrorCode {
    UNAUTHORIZED(401, "未登录，请先登录"),
    FORBIDDEN(403, "没有权限，禁止访问"),
    //未找到资源
    NOT_FOUND(404, "未找到资源"),
    INTERNAL_SERVER_ERROR(500, "服务器异常，请稍后再试"),

    HTTP_UNAUTHORIZED(450, "自动注入异常"),

    //用户删除图像失败
    USER_DELETE_IMAGE_ERROR(710, "用户删除图像失败"),

    //当前方案不唯一
    SCHEME_NOT_UNIQUE(811, "当前方案不唯一"),

    COMPANY_NO_EXIST(1000, "商户不存在"),
    COMPANY_AUT_NOT_OK(1001, "商户待审核或审核不通过"),
    COMPANY_NO_OPEN_WEIXIN(1050, "暂不支持该方式登录"),

    SEND_MOBILE_ERROR(1500,"手机号或验证码错误"),
    SEND_MOBILE_FAST(1501, "发送短信过快，请稍后重试"),
    CAPTCHA_ERROR(1502, "图形验证码错误"),
    MESSAGE_SEND_EXCEED(1550, "今日短信发送已达上限，请联系商家"),

    //未扫码
    NOT_SCAN_CODE(1600, "未扫码"),
    // 未检测到ticket
    QR_CODE_TICKET_NULL(1601, "未检测到ticket"),
    // 二维码错误
    QR_CODE_ERROR(1602, "二维码错误，请联系商家"),


    AI_MODEL_NO_EXIST_CODE(2000, "此AI模型不存在"),
    AI_MODEL_STATUS_DISABLE(2001, "此产品暂停销售"),
    ORDER_ALREADY_EXIST(2006, "此订单号已存在"),
    ORDER_NO_EXIST(2007, "此订单号不存在"),
    DISCOUNT_NO_CONFIG(2008, "折扣未配置"),
    NO_SELECT_DATA(2009, "未查询到数据"),
    SCHEME_NOT_EXIST(2050, "方案不存在"),


    // 用户燃料不足
    SURPLUS_FUEL_NOT_ENOUGH(2300, "燃料不足"),

    COLLECT_NOT_EXIST(2600, "收藏对象不存在"),

    PARAM_NOT_EMPTY(3000, "必填参数不能为空"),


    // comfyui报错信息
    COMFYUI_NOT_MODEL(11001, "请选择模板类型"),
    COMFYUI_NOT_MODEL_TYPE(11002, "请选择对应的模板类型"),
    COMFYUI_UP_PIC(11003, "请上传图片"),
    COMFYUI_INPUT_SIZE(11004, "请输入尺寸"),
    COMFYUI_INPUT_COLOR(11005, "请输入背景颜色"),
    COMFYUI_INPUT_PARAM(11005, "请选择参数"),
    COMFYUI_INPUT_SIZES(11006, "请输入尺寸相关信息"),
    COMFYUI_INPUT_PRIMITIVE(11007, "请输入正向提示词！"),
    COMFYUI_INPUT_OPPOSITEPRIMITIVE(11008, "请输入反向提示词"),
    COMFYUI_INPUT_WIDTH_SIZE(11009, "请输入宽度512-2048"),
    COMFYUI_INPUT_HEIGHT_SIZE(11010, "请输入高度512-2048"),
    COMFYUI_MINIO_CONFIG(11011, "请先配置minio信息"),

    // 数字人报错信息
    NUMERSON_NO(11110, "无效请求"),
    NUMERSON_NO_VIDEO(11111, "请上传视频地址"),
    NUMERSON_NO_VIDEO_NAME(11112, "请定义视频名称"),
    NUMERSON_NO_GREEN(11113, "请定义视频名称"),
    NUMERSON_NO_NUMPERSON(11114, "查无此训练数字人"),
    NUMERSON_NO_FILE(11115, "请上传文件"),
    NUMERSON_NO_TYPE(11116, "请指定类型"),
    NUMERSON_NO_URL(11117, "请输入地址"),
    NUMERSON_NO_NAME(11118, "请输入名称"),
    NUMERSON_NO_TEXT(11119, "请输入文本"),


    NUMERSON_NO_ID(11120, "请输入ID"),
    NUMERSON_NO_SAVE(11121, "保存失败"),
    NUMERSON_NO_BATCH(11122, "请输入批次"),
    NUMERSON_NO_RIGHT_ID(11123, "请输入正确ID"),
    NUMERSON_FAIL_FILE(11124, "文件上传失败"),
    NUMERSON_NO_FILE_TYPE1(11125, "请上传png/jpg/gif文件类型"),
    NUMERSON_NO_FILE_TYPE2(11126, "请上传mp3/wav文件类型"),
    NUMERSON_NO_FILE_TYPE3(11127, "请上传mp4/webm文件类型"),
    NUMERSON_NO_FILE_TYPE4(11128, "请上传png/jpg/gif/mp4/webm文件类型"),
    // 5000自定义编码
    /**
     * 5000  表示法人姓名和身份证的错误码  -认证
     * 5001  表示业务人员姓名和身份证的错误码 -认证
     */
    ;
    private final int code;
    private final String msg;
}
