package com.xyzc.start.controller;


import com.xyzc.common.core.utils.Result;
import com.xyzc.start.domain.*;
import com.xyzc.start.domain.vo.ComfyuiWorkflowVo;
import com.xyzc.start.request.NpRequestParams;
import com.xyzc.start.service.*;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.util.Strings;
import org.springframework.core.io.FileSystemResource;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

@RestController
@RequiredArgsConstructor
@CrossOrigin
@Slf4j
@RequestMapping("/numPerson")
public class NumPersonController {


    private final INumPersonService numPersonService;

    private final INpCommitService npCommitService;

    private final INpQueryService npQueryService;

    private final INpNotifyService npNotifyService;


    /**
     * 提交训练视频
     */
    @PostMapping("/commitTrainVideo")
    @ResponseBody
    public void commitTrainVideo(@RequestBody NpCommitTrain npCommitTrain){
        npCommitService.commitTrainVideo(npCommitTrain);
    }

    /**
     * 训练数字人的查询
     */
    @PostMapping("/queryTrainVideo")
    @ResponseBody
    public Result<List<NpCommitTrain>> queryTrainVideo(@RequestBody NpRequestParams npRequestParams){
        List<NpCommitTrain> npCommitTrains = npQueryService.queryTrainVideo(npRequestParams.getPage(), npRequestParams.getSize());

        return Result.ok(npCommitTrains);
    }

    /**
     * 训练数字人的查询
     */
    @PostMapping("/queryTrainVideoById")
    @ResponseBody
    public void queryTrainVideoById(@RequestParam("id") String id){
        npQueryService.queryTrainVideoById(id);
    }

    /**
     * 提交训练视频的异步通知
     */
    @PostMapping("/commitTrainVedioNotify")
    @ResponseBody
    public String commitTrainVedioNotify(@RequestBody String notify){
        log.info("notify:" + notify);
        if (Strings.isBlank(notify)) {
            return "\n" +
                    "    \"code\": \"1\",\n" +
                    "    \"message\": \"请求失败\",\n" +
                    "    \"success\": false\n";
        }
        npNotifyService.commitTrainVedioNotify(notify);

        return "{\n" +
                "    \"code\": \"0\",\n" +
                "    \"message\": \"请求成功\",\n" +
                "    \"success\": true\n" +
                "}";
    }


    /**
     * 获取公共模特
     *
     * @return
     * @throws Exception
     */
    @PostMapping("/queryCommonTemplate")
    @ResponseBody
    public Result<List<NpTemplate>> queryCommonTemplate(@RequestBody NpRequestParams npRequestParams) throws Exception {
        List<NpTemplate> npTemplateList = npQueryService.queryCommonTemplate( npRequestParams.getPage(), npRequestParams.getSize());
        return Result.ok(npTemplateList);
    }

    /**
     * 查询用户底下的数字人
     *
     * @return
     * @throws Exception
     */
    @PostMapping("/queryTrainingModel")
    @ResponseBody
    public Result<List<NpCommitTrain>> queryTrainingModel(@RequestBody NpRequestParams npRequestParams) throws Exception {
        List<NpCommitTrain> npTemplateList = npQueryService.queryTrainingModel(npRequestParams.getPage(), npRequestParams.getSize());
        return Result.ok(npTemplateList);
    }


    /**
     *上传素材
     * @param file form-data/file	文件
     * @param rootId 素材类型 ，0：背景（图片或者视频），1：图片素材，4：视频素材
     */
    @PostMapping("/uploadMaterial")
    @ResponseBody
    public Result<String> uploadMaterial(MultipartFile file, String rootId){
        npCommitService.uploadMaterial(file, rootId);
        return Result.ok("上传成功");
    }
//    /**
//     * 查询音乐
//     */
//    @PostMapping("/queryMaterial")
//    @ResponseBody
//    public Result<List<NpMaterial>> queryMaterial(NpMaterial material){
//        List<NpMaterial> materials = npQueryService.queryMaterial(material);
//        return Result.ok(materials);
//    }
    /**
     * 查询素材
     * rootId  素材类型 ，0：背景（图片或者视频），1：图片素材，4：视频素材
     * page	   页号默认1
     * size	   每页大小默认10
     * asc	   是否正序, true 正序 false 倒序（默认）
     */
    @PostMapping("/queryMaterial")
    @ResponseBody
    public Result<List<NpMaterial>> queryMaterial(@RequestBody NpRequestParams npRequestParams){
//        npCommitService.queryMaterial(rootId, page, size);
        List<NpMaterial> materials = npQueryService.queryMaterial(npRequestParams.getRootId(), npRequestParams.getPage(), npRequestParams.getSize());
        return Result.ok(materials);
    }

    /**
     *上传音乐
     */
    @PostMapping("/uploadMusic")
    @ResponseBody
    public Result<String> uploadMusic(NpMusic npMusic){
        npCommitService.uploadMusic(npMusic);
        return Result.ok("上传成功");
    }

    /**
     * 查询音乐
     */
    @PostMapping("/queryMusic")
    @ResponseBody
    public Result<List<NpMusic>> QueryMusic(NpMusic npMusic){
        List<NpMusic> npMusics = npQueryService.queryMusic(npMusic);

        return Result.ok(npMusics);
    }

//    /**
//     *上传音乐
//     */
//    @PostMapping("/uploadText")
//    @ResponseBody
//    public Result<String> uploadText(NpText npText){
//        npCommitService.uploadText(npText);
//        return Result.ok("上传成功");
//    }

//    /**
//     * 查询音乐
//     */
//    @PostMapping("/queryText")
//    @ResponseBody
//    public Result<List<NpText>> queryText(NpText npText){
//        List<NpText> npTextList = npQueryService.queryNpText(npText);
//        return Result.ok(npTextList);
//    }


    /**
     * 采集数据
     */
    @PostMapping("/collectData")
    @ResponseBody
    public void collectData() {
        numPersonService.freeModelListQuery();
    }

    /**
     * 获取公司公共声音
     * type 1:硅基公共语音；2:硅基语音克隆；
     * @return
     * @throws Exception
     */
    @PostMapping("/queryCompanySound")
    @ResponseBody
    public Result<List<NpSound>> queryCompanySound(@RequestBody NpRequestParams npRequestParams) throws Exception {
        List<NpSound> companySoundList = npQueryService.queryCompanySound(npRequestParams.getType(), npRequestParams.getPage(), npRequestParams.getSize());
        return Result.ok(companySoundList);
    }


    /**
     * 数字人异步通知
     *
     * @param notify
     * @return
     * @throws Exception
     */
    @PostMapping("/numberPersonCommitNotify")
    @ResponseBody
    public String numberPersonCommitNotify(@RequestBody String notify) throws Exception {
        log.info("notify:{}", notify);
        numPersonService.numberPersonCommitNotify(notify);
        return "{\n" +
                "    \"code\": \"0\",\n" +
                "    \"message\": \"请求成功\",\n" +
                "    \"success\": true\n" +
                "}";
    }

    /**
     * 3.8 合成任务回调接口
     * @param notify
     * @return
     * @throws Exception
     */
    @PostMapping("/composeVedioNotify")
    @ResponseBody
    public String composeVedioNotify(@RequestBody String notify) throws Exception {
        log.info("notify:{}", notify);
        npNotifyService.composeVedioNotify(notify);
        return "{\n" +
                "    \"code\": \"0\",\n" +
                "    \"message\": \"请求成功\",\n" +
                "    \"success\": true\n" +
                "}";
    }

    /**
     * 获取训练任务的详情
     * @param trainingId
     * @return
     */
    @GetMapping("/getTrainingInfo/{trainingId}")
    @ResponseBody
    public Result<Void> getTrainingInfo(@PathVariable("trainingId") String trainingId) {
        numPersonService.getTrainingInfo(trainingId);

        return Result.ok();
    }

    @GetMapping("/getTemplateDraft")
    @ResponseBody
    public Result<List<NpVideoDraft>> getTemplateDraft(String templateId) {
        List<NpVideoDraft> npVideoDraft = numPersonService.getTemplateDraft(templateId);
        return Result.ok(npVideoDraft);
    }

    @PostMapping("/saveTemplateDraft")
    @ResponseBody
    public Result<String> saveTemplateDraft(@RequestBody NpVideoDraft npVideoDraft) {
        numPersonService.saveTemplateDraft(npVideoDraft);
        return Result.ok("保存成功！");
    }
}
