package com.xyzc.start.mapper;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.xyzc.common.mybatis.core.mapper.BaseMapperPlus;
import com.xyzc.start.constant.SchemeConst;
import com.xyzc.start.domain.Scheme;
import com.xyzc.start.domain.bo.CreateOrderBo;
import com.xyzc.start.domain.vo.FuelPackageVo;
import com.xyzc.start.domain.vo.MemberCardVo;
import com.xyzc.start.domain.vo.SchemeVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 方案Mapper接口
 *
 * @author yz
 * @date 2024-06-25
 */
public interface SchemeMapper extends BaseMapperPlus<Scheme, SchemeVo> {

    /**
     * 获取当前会员卡方案
     *
     * @return
     */
    default SchemeVo getCurrentMember() {
        return selectVoOne(new LambdaQueryWrapper<Scheme>()
                //1 生效
                .eq(Scheme::getSchemeStatus, SchemeConst.ACTIVE_STATUS)
                //1 会员卡方案
                .eq(Scheme::getSchemeType, SchemeConst.MEMEBER_TYPE)
        );
    }

    /**
     * 获取当前燃料方案
     */
    default List<SchemeVo> getCurrentFuel() {
        return selectVoList(new LambdaQueryWrapper<Scheme>()
                //1 生效
                .eq(Scheme::getSchemeStatus, SchemeConst.ACTIVE_STATUS)
                //2 燃料方案
                .eq(Scheme::getSchemeType, SchemeConst.FUEL_TYPE)
        );
    }

    /**
     * 根据会员卡id查询方案
     *
     * @param userId
     * @param memberId
     */
    MemberCardVo queryMemberCardByMemberId(Long userId, Long memberId);

    /**
     * 根据燃料id查询方案
     *
     * @param fuelId
     * @return
     */
    List<FuelPackageVo> queryFuelPackageById(Long fuelId);

    /**
     * 判断当前关联的会员卡或者燃料方案是否生效
     *
     * @param bo
     * @return
     */
    Scheme querySchemeByMemberId(@Param("bo") CreateOrderBo bo);

    /**
     * 判断当前关联的会员卡或者燃料方案是否生效
     *
     * @param bo
     * @return
     */
    Scheme querySchemeByFuel(@Param("bo") CreateOrderBo bo);
}
