package com.xyzc.start.service.impl;

import com.xyzc.common.web.security.user.SecurityUser;
import com.xyzc.start.domain.BaseUserFeedback;
import com.xyzc.start.domain.DrawModelFeedBack;
import com.xyzc.start.domain.bo.DrawModelFeedbackBo;
import com.xyzc.start.domain.query.AppQuery;
import com.xyzc.start.domain.query.DiscoveryAppQuery;
import com.xyzc.start.domain.vo.*;
import com.xyzc.start.mapper.*;
import com.xyzc.start.service.IDiscoverService;
import lombok.RequiredArgsConstructor;
import org.apache.http.HttpRequest;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 发现
 *
 * @author 杨兴卓
 */
@Service
@RequiredArgsConstructor
public class DiscoverServiceImpl implements IDiscoverService {

    private final DrawModelMapper drawModelMapper;

    private final DrawGraphicsMapper drawGraphicsMapper;

    private final AppMapper appMapper;
    private final DrawAssistantMapper drawAssistantMapper;
    private final MerchantMapper merchantMapper;
    private final AiModelMapper aiModelMapper;

    private final BaseUserFeedbackMapper baseUserFeedbackMapper;

    /**
     * 根据id返回分页绘画
     *
     * @param graphicsId Long
     * @return
     */
    @Override
    public List<DrawGraphicsSquareVo> queryGraphics(Long graphicsId, String keyword, Long length) {

        return drawGraphicsMapper.queryGraphics(SecurityUser.getUserId(), graphicsId, keyword, length == null ? 20 : length);
    }

    /**
     * 根据上一个id，列表查询模型
     *
     * @param drawModelId
     * @return
     */
    @Override
    public List<DrawModelCollectVo> queryDrawModelList(Long drawModelId, String keyword, Long length) {

        return drawModelMapper.queryDrawModelList(SecurityUser.getUserId(), drawModelId, keyword, length == null ? 20 : length);
    }

    /**
     * 分页查询所有app
     *
     * @return
     */
    @Override
    public List<BaseUserSelectAppVo> queryAppPageList(DiscoveryAppQuery query) {

        return appMapper.queryDiscoveryAppQuery(SecurityUser.getUserId(), query);
    }

    /**
     * 根据promptId查询反向提示词列表
     *
     * @param reversePromptId
     * @param keyword
     * @return
     */
    @Override
    public List<DrawReversePromptVo> queryReversePromptList(Long reversePromptId, String keyword, Integer length) {

        return drawAssistantMapper.queryDrawReservePrompt(reversePromptId, keyword, length == null ? 10 : length);
    }

    /**
     * 查询商家邮箱信息
     *
     * @param request
     * @return
     */
    @Override
    public String queryMail(HttpRequest request) {
        MerchantVo merchantVo = merchantMapper.queryMail(1810310843224322049L);

        return merchantVo.getContactsEmail();
    }

    /**
     * 分页查询大模型备案信息
     *
     * @param appQuery
     * @return
     */
    @Override
    public List<AiModelVo> queryFilingsInfo(AppQuery appQuery) {

        return aiModelMapper.queryFilingsInfo(appQuery);
    }

    /**
     * 反馈内容
     *
     * @param bo
     */
    @Override
    public void drawModelFeedback(DrawModelFeedbackBo bo) {
        BaseUserFeedback drawModelFeedBack = new BaseUserFeedback();
        drawModelFeedBack.setContent(bo.getFeedbackContent());
        drawModelFeedBack.setBaseUserId(SecurityUser.getUserId());

        baseUserFeedbackMapper.insert(drawModelFeedBack);
    }
}
